GIT: unionfs2-2.6.27.y: Unionfs: Accept MS_SILENT during remount

Erez Zadok ezk at fsl.cs.sunysb.edu
Thu Aug 12 23:16:02 EDT 2010


commit cd680814a9c9d19cf45798d4ff106ab74ed4bb2a
Author: Adrian Brunyate <abrunyate at yahoo.com>
Date:   Thu Apr 26 18:51:09 2007 -0400

    Unionfs: Accept MS_SILENT during remount
    
    [jsipek: whitespace cleanup]
    Signed-off-by: Adrian Brunyate <abrunyate at yahoo.com>
    Signed-off-by: Josef 'Jeff' Sipek <jsipek at cs.sunysb.edu>

diff --git a/fs/unionfs/super.c b/fs/unionfs/super.c
index e6a6cc1..ee12d03 100644
--- a/fs/unionfs/super.c
+++ b/fs/unionfs/super.c
@@ -425,11 +425,12 @@ static int unionfs_remount_fs(struct super_block *sb, int *flags,
 	unionfs_write_lock(sb);
 
 	/*
 	 * The VFS will take care of "ro" and "rw" flags, so anything else
 	 * is an error.  So we need to check if any other flags may have
 	 * been passed (none are allowed/supported as of now).
 	 */
-	if ((*flags & ~MS_RDONLY) != 0) {
+	if ((*flags & ~(MS_RDONLY | MS_SILENT)) != 0) {
 		printk(KERN_WARNING
 		       "unionfs: remount flags 0x%x unsupported\n", *flags);
 		err = -EINVAL;
@@ -731,7 +732,8 @@ out_no_change:
 	i = atomic_inc_return(&UNIONFS_SB(sb)->generation);
 	atomic_set(&UNIONFS_D(sb->s_root)->generation, i);
 	atomic_set(&UNIONFS_I(sb->s_root->d_inode)->generation, i);
-	printk("unionfs: new generation number %d\n", i);
+	if (!(*flags & MS_SILENT)) 
+		printk("unionfs: new generation number %d\n", i);
 	err = 0;		/* reset to success */
 
 	/*
@@ -425,11 +425,12 @@ static int unionfs_remount_fs(struct super_block *sb, int *flags,
 
 	/*
-	 * The VFS will take care of "ro" and "rw" flags, so anything else
-	 * is an error.  So we need to check if any other flags may have
-	 * been passed (none are allowed/supported as of now).
+	 * The VFS will take care of "ro" and "rw" flags, and we can safely
+	 * ignore MS_SILENT, but anything else left over is an error.  So we
+	 * need to check if any other flags may have been passed (none are
+	 * allowed/supported as of now).
 	 */


More information about the unionfs-cvs mailing list